<?php

namespace App\Modelos;

use Core\Database;

class EmpleadoSucursales extends Database
{
    protected $table    = 'app_empleados_sucursales';
    protected $id       = 'empsuc_id';

    public function existeSucursal($id_empleado, $id_sucursal)
    {
        return $this->consultar("SELECT * FROM app_empleados_sucursales WHERE sucursal_id=$id_sucursal AND empleado_id=$id_empleado")->row();
    }

    public function obtenerSucursales($id_empleado)
    {
        return $this->consultar("SELECT * FROM app_empleados_sucursales s 
        JOIN app_sucursales su ON s.sucursal_id = su.su_id
        WHERE empleado_id=$id_empleado")->all();
    }

    public function obtenerSucursalEmp($id_empleado)
    {
        return $this->consultar("SELECT * FROM app_empleados_sucursales s 
        JOIN app_sucursales su ON s.sucursal_id = su.su_id
        WHERE empleado_id=$id_empleado")->row();
    }

    public function obtenerSucursal($id_empleado,$id_sucursal)
    {
        return $this->consultar("SELECT * FROM app_empleados_sucursales s 
        JOIN app_sucursales su ON s.sucursal_id = su.su_id
        WHERE sucursal_id=$id_sucursal AND empleado_id=$id_empleado")->row();
    }
    
}
